(***********************************************************************)
(*  v      *   The Coq Proof Assistant  /  The Coq Development Team    *)
(* <O___,, *        INRIA-Rocquencourt  &  LRI-CNRS-Orsay              *)
(*   \VV/  *************************************************************)
(*    //   *      This file is distributed under the terms of the      *)
(*         *       GNU Lesser General Public License Version 2.1       *)
(***********************************************************************)

(* Certification of Imperative Programs / Jean-Christophe Fillitre *)

(*i $Id: pcic.mli,v 1.3 2001/06/27 15:12:30 filliatr Exp $ i*)

open Past
open Rawterm

(* On-the-fly generation of needed (possibly dependent) tuples. *)

val check_product_n : int -> unit
val check_dep_product_n : int -> unit

(* transforms intermediate functional programs into (raw) CIC terms *)

val rawconstr_of_prog : cc_term -> rawconstr

